@@ -21,6 +21,7 @@ MemoryButton::MemoryButton(const QString &text, bool listwidgetbtn, QWidget *par
     , m_effect(new QGraphicsDropShadowEffect(this))
     , m_isallgray(false)
 {
+    qDebug() << "MemoryButton constructor called with text:" << text << "listwidgetbtn:" << listwidgetbtn;
     m_settings = DSettingsAlt::instance();
     setObjectName("MemoryButton");
     m_widgetbtn = listwidgetbtn; //是否是内存列表按键
@@ -34,6 +35,7 @@ MemoryButton::MemoryButton(const QString &text, bool listwidgetbtn, QWidget *par
 
 MemoryButton::~MemoryButton()
 {
+    qDebug() << "MemoryButton destructor called";
     // delete m_effect;
 }
 
@@ -54,6 +56,7 @@ void MemoryButton::init()
  */
 void MemoryButton::animate(bool isspace, int msec)
 {
+    qDebug() << "Button animation triggered with space:" << isspace << "duration:" << msec << "ms";
     if (m_isPress == false) { //edit for bug-20492 20200416
         m_isHover = false;  //edit for bug-20508 20200414
         if (!isspace)
@@ -74,6 +77,7 @@ void MemoryButton::animate(bool isspace, int msec)
  */
 void MemoryButton::setbtnlight(bool light)
 {
+    qInfo() << "Button light state changed to:" << light;
     int mode = m_settings->getOption("mode").toInt();
     if (mode != 1) {
         if (light == true)
